proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-24 by code2llm · Primary language: python · Python: 155, JavaScript: 67, Shell: 8

1,933
Functions
141
Classes
208
Files
53,907
Lines
3
Languages
4.5
Avg CC
174
Critical (CC≥10)
1
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (230)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tasks.jsx | src/proxym/dashboard/components | 1,603 | 96 | 0 | 120
tools.jsx | src/proxym/dashboard/components | 1,563 | 110 | 0 | 87
tickets.jsx | src/proxym/dashboard/components | 1,449 | 87 | 0 | 94
projects.jsx | src/proxym/dashboard/components | 1,095 | 63 | 0 | 61
users.py | src/proxym/dashboard | 912 | 56 | 3 | 13
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
environments.jsx | src/proxym/dashboard/components | 611 | 30 | 0 | 59
__init__.py | src/proxym/tools | 572 | 19 | 5 | 10
setup.jsx | src/proxym/dashboard/components | 554 | 27 | 0 | 17
validate_system.sh | scripts | 531 | 11 | 0 | 0
_environments_api.py | src/proxym/dashboard | 460 | 33 | 6 | 13
_tickets_api.py | src/proxym/dashboard | 457 | 20 | 8 | 17
users.jsx | src/proxym/dashboard/components | 443 | 21 | 0 | 21
__init__.py | src/proxym/accounts | 398 | 20 | 8 | 15
useDashboardData.js | src/proxym/dashboard/hooks | 393 | 62 | 0 | 17
executor.py | src/proxym/tools | 389 | 17 | 3 | 21
_manager.py | src/proxym/dashboard/tickets | 387 | 33 | 1 | 22
human.jsx | src/proxym/dashboard/components | 366 | 18 | 0 | 65
__init__.py | src/proxym/router | 352 | 13 | 1 | 9
repair_agent.py | src/proxym/observability | 341 | 9 | 1 | 14

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TasksPanel | cc_exceeded | 120 | 15
critical | TicketDetailPanel | cc_exceeded | 94 | 15
critical | TicketDispatchTable | cc_exceeded | 87 | 15
critical | TicketsPanel | cc_exceeded | 87 | 15
critical | JobDetailsPanel | cc_exceeded | 77 | 15
critical | ToolHealthPanel | cc_exceeded | 76 | 15
critical | HumanTaskPanel | cc_exceeded | 65 | 15
critical | QuickCreateProject | cc_exceeded | 61 | 15
critical | EnvironmentsPanel | cc_exceeded | 59 | 15
critical | ToolsPanel | cc_exceeded | 57 | 15
critical | TicketsPanel | high_fan_out | 56 | 10
critical | ProjectEditForm | cc_exceeded | 52 | 15
critical | ToolsJobQueue | cc_exceeded | 48 | 15
critical | TasksPanel | high_fan_out | 45 | 10
critical | TicketCard | cc_exceeded | 42 | 15

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
TicketsPanel | 56 | Orchestrates 56 calls
TasksPanel | 45 | Orchestrates 45 calls
EnvironmentsPanel | 42 | Orchestrates 42 calls
useDashboardData | 39 | Orchestrates 39 calls
VoiceChat | 31 | Orchestrates 31 calls
create_ticket | 29 | Create a new ticket. Accepts 'task' (new) or 'title' (legacy).
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
QuickTaskCreator | 27 | Orchestrates 27 calls
TicketDispatchTable | 27 | 27-way dispatch

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split _enrich_project (CC=28 → target CC<10) | high | low
2 | Split _apply_runtime_health (CC=28 → target CC<10) | high | low
3 | Split DiagnosticsPanel (CC=26 → target CC<10) | high | low
4 | Split LogPanel (CC=34 → target CC<10) | high | low
5 | Split HumanTaskPanel (CC=65 → target CC<10) | high | low
6 | Split VMsPanel (CC=36 → target CC<10) | high | low
7 | Split _resolveJobEnvironment (CC=25 → target CC<10) | high | low
8 | Split TaskCardMeta (CC=37 → target CC<10) | high | low
9 | Split TaskJobBadge (CC=25 → target CC<10) | high | low
10 | Split TaskBulkEditBar (CC=30 → target CC<10) | high | low
11 | Split QuickTaskCreator (CC=31 → target CC<10) | high | low
12 | Split TasksPanel (CC=120 → target CC<10) | high | low
13 | Split ProjectCard (CC=28 → target CC<10) | high | low
14 | Split QuickCreateProject (CC=61 → target CC<10) | high | low
15 | Split ProjectEditForm (CC=52 → target CC<10) | high | low